@@ -2,7 +2,7 @@ package InfluxDB::LineProtocol;
 use strict;
 use warnings;
 
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 
 # ABSTRACT: Write and read InfluxDB LineProtocol
 
@@ -57,37 +57,23 @@ sub data2line {
         $timestamp *= 10 if length($timestamp) < 19;
     }
 
-    # $fields can be a hashref or a scalar
-    my $fields;
-    my $ref_values = ref($values);
-    if ( $ref_values eq 'HASH' ) {
-        my @fields;
-        foreach my $k ( sort keys %$values ) {
-            my $v = $values->{$k};
-            $k =~ s/([, ])/\\$1/g;
+    # If values is not a hashref, convert it into one
+    $values = { value => $values } if (not ref($values));
 
-            # TODO handle booleans
-            # TODO handle negative, exponentials
-            if ( $v =~ /[^\d\.]/ ) {
-                $v =~ s/"/\\"/g;
-                $v = '"' . $v . '"';
-            }
-            push( @fields, $k . '=' . $v );
+    my @fields;
+    foreach my $k ( sort keys %$values ) {
+        my $v = $values->{$k};
+        $k =~ s/([, ])/\\$1/g;
+
+        # TODO handle booleans
+        # TODO handle exponentials
+        if ( $v !~ /^-?\d+(?:\.\d+)?$/ ) {
+            $v =~ s/"/\\"/g;
+            $v = '"' . $v . '"';
         }
-        $fields = join( ',', @fields );
-    }
-    elsif ( !$ref_values ) {
-        if ( $values =~ /[^\d\.]/ ) {
-            $values =~ s/([, ])/\\$1/g;
-            $fields = 'value="' . $values . '"';
-        }
-        else {
-            $fields = 'value=' . $values;
-        }
-    }
-    else {
-        croak("Invalid fields $ref_values");
+        push( @fields, $k . '=' . $v );
     }
+    my $fields = join( ',', @fields );
 
     return sprintf( "%s %s %s", $key, $fields, $timestamp );
 }
@@ -139,7 +125,7 @@ InfluxDB::LineProtocol - Write and read InfluxDB LineProtocol
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
@@ -206,8 +192,6 @@ C<tags_hashref> is undef if there are no tags!
 
 =item * handle boolean values
 
-=item * handle negative values
-
 =item * handle exponential values
 
 =back
@@ -216,15 +200,27 @@ C<tags_hashref> is undef if there are no tags!
 
 =over
 
-=item * L<InfluxDB> provides access to the old 0.8 API. It also allows searching etc.
+=item * L<InfluxDB|https://metacpan.org/pod/InfluxDB> provides access to the old 0.8 API. It also allows searching etc.
 
 =back
 
 =head1 THANKS
 
-Thanks to L<validad.com|http://www.validad.com/> for funding the
+Thanks to
+
+=over
+
+=item *
+
+L<validad.com|http://www.validad.com/> for funding the
 development of this code.
 
+=item *
+
+L<Jose Luis Martinez|https://github.com/pplu> for implementing negative number support.
+
+=back
+
 =head1 AUTHOR
 
 Thomas Klausner <domm@cpan.org>
